@@ -23,16 +23,13 @@
 
 #include "mapitems.h"
 
+#include <QBrush>
 #include <QGraphicsScene>
 #include <QPainter>
-#include <QBrush>
 #include <QTimer>
 
-#include <kiconloader.h>
-#include <kglobalsettings.h>
-#include <klocale.h>
-#include <kdebug.h>
-#include <kcolorscheme.h>
+#include <KLocalizedString>
+#include <KColorScheme>
 
 #include "mapscene.h"
 #include "map.h"
@@ -54,11 +51,11 @@ PlanetItem::PlanetItem (MapScene *scene, Sector *sector, Game *game)
     if (m_sector->planet() != NULL) {
         m_lookName = QString("planet_%1").arg(m_sector->planet()->planetLook() + 1);
     }
-    setAcceptsHoverEvents(true);
+    setAcceptHoverEvents(true);
 
     m_blinkTimer = new QTimer(this);
-    connect(m_blinkTimer, SIGNAL(timeout()), this, SLOT(blinkPlanet()));
-    connect(m_sector,     SIGNAL(update()),  this, SLOT(updatePlanet()));
+    connect(m_blinkTimer, &QTimer::timeout, this, &PlanetItem::blinkPlanet);
+    connect(m_sector, &Sector::update, this, &PlanetItem::updatePlanet);
 }
 
 
@@ -145,12 +142,12 @@ QPixmap PlanetItem::renderPixmap( const QString& svgId, int width, int height )
 {
     QPixmap pix;
     QString cacheKey = QString("%1%2x%3").arg(svgId).arg(width).arg(height);
-    if (!m_scene->pixmapCache()->find(cacheKey, pix)) {
+    if (!m_scene->imageCache()->findPixmap(cacheKey, &pix)) {
         pix = QPixmap(width, height);
         pix.fill(Qt::transparent);
         QPainter pixPainter(&pix);
         m_scene->renderer()->render(&pixPainter, svgId, QRect(0, 0, width, height));
-        m_scene->pixmapCache()->insert(cacheKey, pix);
+        m_scene->imageCache()->insertPixmap(cacheKey, pix);
     }
 
     return pix;
@@ -238,7 +235,7 @@ void PlanetInfoItem::setPlanet (Planet *planet)
         if( m_game->currentPlayer() == planet->player() )
         {
             int shipsNeeded = 0; // determine how many ships will be needed by standing orders
-            foreach(AttackFleet* fleet, planet->player()->standingOrders()) {
+            for (AttackFleet* fleet : planet->player()->standingOrders()) {
                 if(fleet->source == planet)
                     shipsNeeded += fleet->shipCount();
             }
