@@ -23,8 +23,6 @@
 
 class AiDefault : public ComputerPlayer
 {
-    Q_OBJECT
-
 protected:
     enum AiLevel { Weak, Normal, Hard };
 
@@ -34,11 +32,7 @@ protected:
 
     AiLevel aiLevel() const { return m_level; }
 
-    virtual void play();
-
-signals:
-
-public slots:
+    void play() override;
 
 private:
     AiLevel m_level;
